@@ -4,7 +4,7 @@ from globus_portal_framework.exc import (
     GlobusPortalException, PreviewPermissionDenied, PreviewServerError,
     PreviewException, PreviewBinaryData, PreviewNotFound, PreviewURLNotFound,
     ExpiredGlobusToken, IndexNotFound,
-    GroupsException,
+    GroupsException, PortalAuthException,
 )
 
 from globus_portal_framework.gclients import (
@@ -32,7 +32,7 @@ __all__ = [
     'GlobusPortalException', 'PreviewPermissionDenied', 'PreviewServerError',
     'PreviewException', 'PreviewBinaryData', 'PreviewNotFound',
     'PreviewURLNotFound', 'ExpiredGlobusToken', 'IndexNotFound',
-    'GroupsException',
+    'GroupsException', 'PortalAuthException',
 
     'load_auth_client', 'load_transfer_client', 'load_search_client',
     'load_globus_client', 'load_globus_access_token', 'validate_token',
