@@ -6,6 +6,8 @@ import logging
 import math
 import collections
 import datetime
+import pathlib
+from packaging import version
 from urllib.parse import quote_plus, unquote
 import globus_sdk
 from django import template
@@ -115,7 +117,7 @@ def post_search(index, query, filters, user=None, page=1, search_kwargs=None):
         etext = ('There was an error in {}, you can file '
                  'an issue here:\n{}\nWith the following data: \n\n')
         gs = 'https://github.com/globusonline/globus-search/issues'
-        dgpf = 'https://github.com/globusonline/django-globus-portal-framework'
+        dgpf = 'https://github.com/globus/django-globus-portal-framework'
         if str(sapie.http_status).startswith('5'):
             error = etext.format('Globus Search', gs)
         else:
@@ -367,12 +369,38 @@ def prepare_search_facets(facets):
             raise ValueError('Each facet must define at minimum "field_name"')
         cfacet['name'] = generate_globus_search_facet_name(facet, idx)
         cfacet['type'] = cfacet.get('type', 'terms')
-        if cfacet['type'] != 'date_histogram':
+        if cfacet['type'] not in ['date_histogram', 'sum', 'avg']:
             cfacet['size'] = cfacet.get('size', 10)
         cleaned_facets.append(cfacet)
     return cleaned_facets
 
 
+def get_template_path(template, index=None):
+    """Get the base template path to a given template
+    set and return the setting prefix with the ``template`` given.
+    The template set can either be a setting per-index with the
+    ``base_templates`` setting, or global as ``BASE_TEMPLATES``
+    in settings.py.
+
+    This is primarily used to allow operation between newer Globus Portal
+    Framework templates (globus_portal_framework/v2) and older versions
+    of templates. This would also allow users to draft an entirely new set
+    of base templates, if they wished.
+
+    :param template: Path to template. Ex: search.html
+    :param index: The name of the index (key in SEARCH_INDEXES). Optional.
+
+
+    """
+    index_data = get_index(index) if index is not None else {}
+    prefix = (
+            index_data.get('base_templates') or
+            get_setting('BASE_TEMPLATES') or
+            ''
+    )
+    return str(pathlib.Path(prefix) / template)
+
+
 def get_template(index, base_template):
     """If a user has defined a custom template for visualizing search data for
     their index, load that template. Otherwise, load the default template.
@@ -415,8 +443,11 @@ def get_subject(index, subject, user=None):
     client = load_search_client(user)
     try:
         idata = get_index(index)
-        result = client.get_subject(idata['uuid'], unquote(subject),
-                                    result_format_version='2017-09-01')
+        if version.parse(globus_sdk.version.__version__).major < 3:
+            params = dict(result_format_version='2017-09-01')
+        else:
+            params = dict(query_params=dict(result_format_version='2017-09-01'))
+        result = client.get_subject(idata['uuid'], unquote(subject), **params)
         return process_search_data(idata.get('fields', {}), [result.data])[0]
     except globus_sdk.SearchAPIError:
         return {'subject': subject, 'error': 'No data was found for subject'}
@@ -453,7 +484,8 @@ def process_search_data(field_mappers, results):
             field = {}
             if isinstance(mapper, str):
                 field = {mapper: default_content.get(mapper)}
-            elif isinstance(mapper, collections.Iterable) and len(mapper) == 2:
+            elif isinstance(mapper, collections.abc.Iterable) \
+                    and len(mapper) == 2:
                 field_name, map_approach = mapper
                 if isinstance(map_approach, str):
                     field = {field_name: default_content.get(map_approach)}
